Documentation
¶
Index ¶
- type IndexFS
- type PatchFS
- type RemoteFS
- type SyncFS
- func (sfs *SyncFS) Chmod(name string, mode fs.FileMode) error
- func (sfs *SyncFS) Chown(name string, uid, gid int) error
- func (sfs *SyncFS) Chtimes(name string, atime, mtime time.Time) error
- func (sfs *SyncFS) Close() error
- func (sfs *SyncFS) Create(name string) (fs.File, error)
- func (sfs *SyncFS) Mkdir(name string, perm fs.FileMode) error
- func (sfs *SyncFS) Open(name string) (fs.File, error)
- func (sfs *SyncFS) OpenContext(ctx context.Context, name string) (f fs.File, err error)
- func (sfs *SyncFS) OpenFile(name string, flag int, perm fs.FileMode) (f fs.File, err error)
- func (sfs *SyncFS) ReadDir(name string) (entries []fs.DirEntry, err error)
- func (sfs *SyncFS) Readlink(name string) (string, error)
- func (sfs *SyncFS) Remove(name string) error
- func (sfs *SyncFS) Rename(oldname, newname string) error
- func (sfs *SyncFS) Stat(name string) (fs.FileInfo, error)
- func (sfs *SyncFS) StatContext(ctx context.Context, name string) (info fs.FileInfo, err error)
- func (sfs *SyncFS) Symlink(oldname, newname string) error
- func (sfs *SyncFS) Sync() error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SyncFS ¶
type SyncFS struct {
// contains filtered or unexported fields
}
SyncFS provides a filesystem that syncs between local and remote filesystems. All operations are applied to local first, then synced to remote.
func (*SyncFS) OpenContext ¶
OpenContext opens a file with context from local
func (*SyncFS) StatContext ¶
StatContext returns file info with context from local
Click to show internal directories.
Click to hide internal directories.